@@ -24,6 +24,7 @@ import "src/ng/http.js";
 import "src/ng/httpBackend.js";
 import "src/ng/interpolate.js";
 import "src/ng/interval.js";
+import "src/ng/intervalFactory.js";
 import "src/ng/jsonpCallbacks.js";
 import "src/ng/locale.js";
 import "src/ng/location.js";
@@ -36,6 +37,7 @@ import "src/ng/rootElement.js";
 import "src/ng/sanitizeUri.js";
 import "src/ng/sce.js";
 import "src/ng/sniffer.js";
+import "src/ng/taskTrackerFactory.js";
 import "src/ng/templateRequest.js";
 import "src/ng/testability.js";
 import "src/ng/timeout.js";
@@ -44,7 +46,6 @@ import "src/ng/window.js";
 import "src/ng/cookieReader.js";
 
 import "src/ng/filter.js";
-import "src/ng/cookieReader.js";
 import "src/ng/filter/filter.js";
 import "src/ng/filter/filters.js";
 import "src/ng/filter/limitTo.js";
@@ -71,6 +72,7 @@ import "src/ng/directive/ngModelOptions.js";
 import "src/ng/directive/ngNonBindable.js";
 import "src/ng/directive/ngOptions.js";
 import "src/ng/directive/ngPluralize.js";
+import "src/ng/directive/ngRef.js";
 import "src/ng/directive/ngRepeat.js";
 import "src/ng/directive/ngShowHide.js";
 import "src/ng/directive/ngStyle.js";
